SISCone : Main Page

# SISCone Documentation

### Version 3.0.6

SISCone is a Seedless Infrared Safe Cone jet algorithm.

It was developped by Gavin Salam and Gregory Soyez. It is available as a library, as a standalone program or as a FastJet (>= 2.1) plugin.

News (June 20 2023): We have released a new version of SISCone (v3.0.6). This minor release removed the default -ffast-math compilation flag that was causing potential interference with other codes (thanks to Matthew Feickert). Relative to the 2.0.X series, SISCone 3.0.X adds the option of running SISCone with progressive removal (instead of the standard split-merge step). This version will be available in FastJet(>=3.4.2).

The algorithm is described in the publication JHEP 05 (2007) 086 [arXiv:0704.0292 [hep-ph]]. See the links below for more detailed information.

Useful links

- How to use SISCone
- Download SISCone
- Description of the algorithm
- Algorithm performance
- Developer documentation (built from the code using doxygen)
- SISCone webpage on HEPForge
- SISCone git repository on GitLab

Home
Contacts: Gregory Soyez Gavin Salam